@@ -252,7 +252,7 @@ class ADAuth(LoginManager):
         app.config.setdefault("AD_APP_ID", None)
         app.config.setdefault("AD_APP_KEY", None)
         app.config.setdefault("AD_REDIRECT_URI", None)
-        app.config.setdefault("AD_DOMAIN_FOR_GROUPS", "smaxtec.com")
+        app.config.setdefault("AD_DOMAIN_FOR_GROUPS", "example.com")
         app.config.setdefault("AD_AUTH_URL", 'https://login.microsoftonline.com/common/oauth2/authorize')
         app.config.setdefault("AD_TOKEN_URL", 'https://login.microsoftonline.com/common/oauth2/token')
         app.config.setdefault("AD_GRAPH_URL", 'https://graph.windows.net')
@@ -295,7 +295,7 @@ class ADAuth(LoginManager):
         super(ADAuth, self).init_app(
             app=app, add_context_processor=add_context_processor)
 
-        self.user_callback = self.load_user
+        self.user_loader(self.load_user)
 
     def setDatabaseClass(self, my_class):
         if self.connected:
